@@ -4,21 +4,21 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(package_exists);
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 sub package_exists {
     my $pkg = shift;
 
     return unless $pkg =~ /\A\w+(::\w+)*\z/;
     if ($pkg =~ s/::(\w+)\z//) {
-        return ${$pkg . "::"}{$1 . "::"} ? 1:0;
+        return !!${$pkg . "::"}{$1 . "::"};
     } else {
-        return $::{$pkg . "::"} ? 1:0;
+        return !!$::{$pkg . "::"};
     }
 }
 
 1;
-# ABSTRACT: Array-related utilities
+# ABSTRACT: Package-related utilities
 
 
 __END__
@@ -26,11 +26,11 @@ __END__
 
 =head1 NAME
 
-SHARYANTO::Package::Util - Array-related utilities
+SHARYANTO::Package::Util - Package-related utilities
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -40,6 +40,19 @@ version 0.12
 
 =head1 DESCRIPTION
 
+=head1 FUNCTIONS
+
+None are exported by default, but they can be.
+
+=head2 package_exists($name) => BOOL
+
+Return true if package "exists". By "exists", it means that the package has been
+defined by C<package> statement or some entries have been created in the symbol
+table (e.g. C<$Foo::var = 1;> will make the C<Foo> package "exist").
+
+This function can be used e.g. for checking before aliasing one package to
+another. Or to casually check whether a module has been loaded.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
